import pytest


async def init():
    # Initialise SQLite DB and specify the app name of "models"
    #  alongside the models "article.models"
    from tortoise import Tortoise

    await Tortoise.init(
        db_url="sqlite://:memory:",
        # db_url="sqlite://tortoise_db.sqlite3",
        modules={"models": ["article.models"]},
    )
    # Generate the schema
    await Tortoise.generate_schemas()


@pytest.fixture(scope="session", autouse=True)
def setup_database():
    """Create all tables once before any tests run."""
    from tortoise import run_async

    run_async(init())



import pytest


@pytest.fixture(scope="session", autouse=True)
def setup_database():
    """Create all tables once before any tests run."""
    from config import create_tables  # noqa
    from article.models import Article, Group, User  # noqa

    create_tables()



from fake import FAKER, TextPdfGenerator

texts = ["Page 1 content", "Page 2 content", "Page 3 content"]
pdf_bytes = FAKER.pdf(texts=texts, generator=TextPdfGenerator)

assert isinstance(pdf_bytes, bytes)



import pytest


@pytest.fixture(scope="session", autouse=True)
def setup_database():
    """Create all tables before any tests run, and drop them when the
    session ends.
    """
    from article.models import Base
    from config import ENGINE

    Base.metadata.create_all(ENGINE)
    yield
    Base.metadata.drop_all(ENGINE)


@pytest.fixture(scope="function")
def db_session():
    """Provide a new database session for a test and roll back after each
    test.
    """
    from sqlalchemy.orm import sessionmaker

    from config import ENGINE

    # Establish a connection and start a transaction
    connection = ENGINE.connect()
    transaction = connection.begin()

    # Bind a sessionmaker to the connection
    session_cls = sessionmaker(bind=connection)
    session = session_cls()

    try:
        yield session
    finally:
        # Roll back any changes and close resources
        session.close()
        transaction.rollback()
        connection.close()



"""
Configuration hooks for `pytest`. Normally this wouldn't be necessary,
but since `pytest-codeblock` is used, we want to clean-up files generated by
running documentation tests. Therefore, this hook, which simply
calls the `clean_up` method of the `FILE_REGISTRY` instance.
"""

from fake import FILE_REGISTRY
from pytest_codeblock.constants import CODEBLOCK_MARK

__author__ = "Artur Barseghyan <artur.barseghyan@gmail.com>"
__copyright__ = "2023-2025 Artur Barseghyan"
__license__ = "MIT"
__all__ = ("pytest_runtest_teardown",)


def pytest_runtest_teardown(item, nextitem):
    """Clean up after test ends."""
    if item.get_closest_marker(CODEBLOCK_MARK):
        FILE_REGISTRY.clean_up()



from pathlib import Path

from fake import FAKER, FileSystemStorage, TextPdfGenerator

BASE_DIR = Path(__file__).resolve().parent.parent if "__file__" in globals() else Path.cwd()  # noqa
MEDIA_ROOT = BASE_DIR / "media"

STORAGE = FileSystemStorage(root_path=MEDIA_ROOT, rel_path="tmp")

pdf_file = FAKER.pdf_file(generator=TextPdfGenerator, storage=STORAGE)

assert isinstance(pdf_file, str)
assert pdf_file.data["storage"].exists(pdf_file)
